stats::chisq.test, which applies a continuity correction.A shortcut wrapper function to get the observed test statistic for a chisq test. Uses stats::chisq.test, which applies a continuity correction.
chisq_stat(data, formula, ...)a data frame that can be coerced into a tibble
a formula with the response variable on the left and the explanatory on the right
additional arguments for chisq.test